@@ -16,18 +16,18 @@ class OTP(JSON):
 
     @staticmethod
     def _otp(item):
-        otp = "otpauth://%s/totp-secret?" % item.get('type', 'totp').lower()
-        otp += "secret=%s&issuer=%s" % (item['secret'], item['label'])
+        otp = f"otpauth://{item.get('type', 'totp').lower()}/totp-secret?"
+        otp += f"secret={item['secret']}&issuer={item['label']}"
         for setting in ['algorithm', 'digits', 'counter', 'period']:
             if setting in item:
-                otp += "&%s=%s" % (setting, item[setting])
+                otp += f"&{setting}={item[setting]}"
         return otp
 
     def parse(self):
         """Parse OTP based file."""
         jsons = json.loads(self.content)
         for item in jsons:
-            entry = dict()
+            entry = {}
             entry['title'] = item['label']
             entry['otpauth'] = self._otp(item)
 
@@ -40,5 +40,5 @@ class OTP(JSON):
 
     def open(self):
         """Parse OTP based file."""
-        super(OTP, self).open()
+        super().open()
         self.content = self.file.read()
